@@ -2,20 +2,20 @@ from scanner3d.scanner.scanner import Scanner
 from scanner3d.camera3d import Camera3D, Camera3DTypes
 from scanner3d.geo import Position, ZRange
 from lensguild.objective import  ObjectivesDB
-from lensguild.sensor import SensorsDB
+from isensor.sensors_db import SensorsDB
 from allytools.units import Length, LengthUnit
 from typing import  Final
 
 Eva2A: Final[Scanner] = Scanner(
-    name="Eva2A CIL085",
+    name="Eva2A",
     cameras=(Camera3D(name="ReconCam0",
                       type=Camera3DTypes.Reconstruction,
-                      objective=ObjectivesDB.CIL085_F4_4_M12BNIR,
+                      objective=ObjectivesDB.CIL085_F4_4_M12B_NIR,
                       sensor=SensorsDB.SONY_IMX900,
                       position=Position(0, 0, 0, 0, 0, 0),
                       z_range=ZRange(z_min=Length(350.0),
                                      z_max=Length(800.0),
                                      z_focus=Length(550.0)),
-                      primary_wavelength=Length(0.450, LengthUnit.UM)),
+                      primary_wavelength=Length(450, LengthUnit.NM)),
              ),
 )
\ No newline at end of file
