@@ -2,7 +2,7 @@ from scanner3d.scanner.scanner import Scanner
 from scanner3d.camera3d import Camera3D, Camera3DTypes
 from scanner3d.geo import Position, ZRange
 from lensguild.objective import  ObjectivesDB
-from lensguild.sensor import SensorsDB
+from isensor.sensors_db import SensorsDB
 from allytools.units import Length, LengthUnit
 from typing import  Final
 
@@ -16,6 +16,6 @@ Spider2ProC: Final[Scanner] = Scanner(
                       z_range=ZRange(z_min=Length(190.0),
                                      z_max=Length(350.0),
                                      z_focus=Length(240.0)),
-                      primary_wavelength=Length(0.450, LengthUnit.UM)),
+                      primary_wavelength=Length(450, LengthUnit.NM)),
              ),
 )
\ No newline at end of file
