@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Any, Protocol
+from typing import TYPE_CHECKING, Protocol
 from scanner3d.zemod.core.native_adapter import NativeAdapter
 
 if TYPE_CHECKING:
@@ -17,5 +17,5 @@ class ZeModIAS(NativeAdapter["IAS_"]):
     def set_field_number(self, n: int) -> None:
         self.native.Field.SetFieldNumber(n)
 
-    def apply(self, settings: ZeModIASSettings) -> None:
+    def apply_settings(self, settings: ZeModIASSettings) -> None:
         settings.apply_to(self)
\ No newline at end of file
